@@ -173,7 +173,7 @@ class ListLogStoreResponse(LogResponse):
             raise ValueError("passed response is not a ListLogstoresResponse: " + str(type(response)))
 
         self.count += response.get_count()
-        self.total = response.get_total() # use the latest total count
+        self.total_count = response.get_total() # use the latest total count
         self.logstores.extend(response.get_logstores())
 
         # update body
@@ -191,4 +191,4 @@ class ListLogStoreResponse(LogResponse):
 
     @property
     def logstores(self):
-        return self._logstores
\ No newline at end of file
+        return self._logstores
